Security Advisories (1)
CVE-2025-15578 (2026-02-16)

Maypole versions from 2.10 through 2.13 for Perl generates session ids insecurely. The session id is seeded with the system time (which is available from HTTP response headers), a call to the built-in rand() function, and the PID.

NAME

Maypole::Model::CDBI::Plain - Class::DBI model without ::Loader

SYNOPSIS

package Foo;
use base 'Maypole::Application';
use Foo::SomeTable;
use Foo::Other::Table;

Foo->config->model("Maypole::Model::CDBI::Plain");
Foo->setup([qw/ Foo::SomeTable Foo::Other::Table /]);

DESCRIPTION

This module allows you to use Maypole with previously set-up Class::DBI classes; simply call setup with a list reference of the classes you're going to use, and Maypole will work out the tables and set up the inheritance relationships as normal.

METHODS

setup_database
class_of

See Maypole::Model::Base